aboutsummaryrefslogtreecommitdiff
path: root/src/soc/intel/apollolake/mmap_boot.c
diff options
context:
space:
mode:
authorJulius Werner <jwerner@chromium.org>2019-11-08 13:06:20 -0800
committerJulius Werner <jwerner@chromium.org>2019-11-14 03:31:17 +0000
commit32e13c0b003eab6941236fc04d0299f6a0bf0ca2 (patch)
treeb842fd1588fd12036628a98a5022c505fd5552ed /src/soc/intel/apollolake/mmap_boot.c
parentcefe89ee7916b2c1fd6401456313f8a4d110735c (diff)
cbfs: Stop checking master header
The CBFS master header is a legacy structure that just conveys the same information we already have from the FMAP these days. We're still including it to support older CBFS implementations in some payloads, but there's no need for coreboot itself to follow this indirection anymore. This patch simplifies the default CBFS locator to just return the CBFS offset and size from the FMAP directly. Change-Id: I6b00dd7f276364d62fa1f637efbaee0e80607c49 Signed-off-by: Julius Werner <jwerner@chromium.org> Reviewed-on: https://review.coreboot.org/c/coreboot/+/36688 Reviewed-by: Wim Vervoorn <wvervoorn@eltan.com> Reviewed-by: Aaron Durbin <adurbin@chromium.org> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'src/soc/intel/apollolake/mmap_boot.c')
-rw-r--r--src/soc/intel/apollolake/mmap_boot.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/soc/intel/apollolake/mmap_boot.c b/src/soc/intel/apollolake/mmap_boot.c
index 614b6031c4..631a834160 100644
--- a/src/soc/intel/apollolake/mmap_boot.c
+++ b/src/soc/intel/apollolake/mmap_boot.c
@@ -128,10 +128,10 @@ static int iafw_boot_region_properties(struct cbfs_props *props)
}
/*
* Named cbfs_master_header_locator so that it overrides the default, but
* incompatible locator in cbfs.c
*/
-const struct cbfs_locator cbfs_master_header_locator = {
+const struct cbfs_locator cbfs_default_locator = {
.name = "IAFW Locator",
.locate = iafw_boot_region_properties,
};
@@ -128,10 +128,10 @@ static int iafw_boot_region_properties(struct cbfs_props *props)
}
/*
- * Named cbfs_master_header_locator so that it overrides the default, but
- * incompatible locator in cbfs.c
+ * Named cbfs_default_locator so that it overrides the default, but incompatible
+ * locator in cbfs.c
*/